@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2015      Mikhail Ivchenko <ematirov@gmail.com>
+// SPDX-FileCopyrightText: 2015 Mikhail Ivchenko <ematirov@gmail.com>
 //
 
 #ifndef ADDLINKDIALOG_H
@@ -23,8 +18,8 @@ class MARBLE_EXPORT AddLinkDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit AddLinkDialog(QWidget *parent = 0 );
-    ~AddLinkDialog();
+    explicit AddLinkDialog(QWidget *parent = nullptr );
+    ~AddLinkDialog() override;
     QString name() const;
     QString url() const;
 
