@@ -6,6 +6,8 @@
 #include <QDialog>
 #include <QVector>
 
+#include <MarbleGlobal.h>
+
 #include "marble_export.h"
 
 namespace Marble
@@ -22,7 +24,7 @@ class MARBLE_EXPORT DownloadRegionDialog: public QDialog
     enum SelectionMethod { VisibleRegionMethod, SpecifiedRegionMethod, RouteDownloadMethod };
 
     explicit DownloadRegionDialog( MarbleWidget *const widget, QWidget * const parent = nullptr,
-                                   Qt::WindowFlags const f = nullptr );
+                                   Qt::WindowFlags const f = Qt::WindowFlags() );
     ~DownloadRegionDialog() override;
     void setAllowedTileLevelRange( int const minimumTileLevel,
                                    int const maximumTileLevel );
@@ -31,10 +33,13 @@ class MARBLE_EXPORT DownloadRegionDialog: public QDialog
 
     QVector<TileCoordsPyramid> region() const;
 
+    TileType tileType() const;
+
  public Q_SLOTS:
     void setSpecifiedLatLonAltBox( GeoDataLatLonAltBox const & );
     void setVisibleLatLonAltBox( GeoDataLatLonAltBox const & );
-    void updateTextureLayer();
+    void updateTileLayer();
+    void delayUpdateTileLayer();
 
  Q_SIGNALS:
     /// This signal is emitted when the "Apply" button is pressed.
@@ -50,7 +55,8 @@ class MARBLE_EXPORT DownloadRegionDialog: public QDialog
 
  private Q_SLOTS:
     void toggleSelectionMethod();
-    void updateTilesCount();
+    void updateTileCount();
+    void updateTileType();
 
     /// This slot is called upon to update the route download UI when a route exists
     void updateRouteDialog();
