@@ -305,6 +305,8 @@ MapViewWidget::MapViewWidget( QWidget *parent, Qt::WindowFlags f )
         d->m_mapViewUi.marbleThemeSelectView->setModel( &d->m_mapSortProxy );
         connect( d->m_mapViewUi.marbleThemeSelectView, SIGNAL(pressed(QModelIndex)),
                  this,                                 SLOT(mapThemeSelected(QModelIndex)) );
+        connect( d->m_mapViewUi.marbleThemeSelectView, SIGNAL(activated(QModelIndex)),
+                 this,                                 SLOT(mapThemeSelected(QModelIndex)) );
         connect( d->m_mapViewUi.marbleThemeSelectView, SIGNAL(customContextMenuRequested(QPoint)),
                  this,                                 SLOT(showContextMenu(QPoint)) );
 
@@ -641,6 +643,7 @@ QString MapViewWidget::Private::favoriteKey(const QModelIndex &index) const
 
 void MapViewWidget::Private::showContextMenu( const QPoint& pos )
 {
+    qDebug() << Q_FUNC_INFO;
     Q_UNUSED(pos)
     QMenu menu;
 
@@ -656,6 +659,7 @@ void MapViewWidget::Private::showContextMenu( const QPoint& pos )
     if (QFileInfo(MarbleDirs::localPath() + QLatin1String("/maps/") + currentThemePath()).exists()) {
         menu.addAction( tr( "&Delete Map Theme" ), q, SLOT(deleteMap()) );
     }
+    menu.exec( m_mapViewUi.marbleThemeSelectView->mapToGlobal( pos ) );
 }
 
 void MapViewWidget::Private::deleteMap()
