@@ -1,13 +1,8 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2005-2007 Torsten Rahn <tackat@kde.org>
-// Copyright 2007      Inge Wallin  <ingwa@kde.org>
-// Copyright 2014      Adam Dabrowski <adamdbrw@gmail.com>
+// SPDX-FileCopyrightText: 2005-2007 Torsten Rahn <tackat@kde.org>
+// SPDX-FileCopyrightText: 2007 Inge Wallin <ingwa@kde.org>
+// SPDX-FileCopyrightText: 2014 Adam Dabrowski <adamdbrw@gmail.com>
 //
 
 #ifndef MARBLE_MARBLEWIDGETINPUTHANDLER_H
@@ -15,6 +10,7 @@
 
 #include <QObject>
 #include <QSharedPointer>
+#include <QPinchGesture>
 #include "MarbleInputHandler.h"
 
 namespace Marble
@@ -42,9 +38,13 @@ private Q_SLOTS:
 
 private:
     bool handleKeyPress(QKeyEvent* event) override;
+    bool handleTouch(QTouchEvent *event) override;
+    bool handleGesture(QGestureEvent *e) override;
     AbstractSelectionRubber *selectionRubber() override;
     bool layersEventFilter(QObject *o, QEvent *e) override;
 
+    void handlePinchGesture(QPinchGesture *pinch);
+
     using MarbleWidgetInputHandlerPrivatePtr = QSharedPointer<MarbleWidgetInputHandlerPrivate>;
     MarbleWidgetInputHandlerPrivatePtr d;
     friend class MarbleWidgetInputHandlerPrivate;
