@@ -172,11 +172,7 @@ void MovieCapture::recordFrame()
         d->process.start( d->encoderExec, arguments );
         connect(&d->process, SIGNAL(finished(int)), this, SLOT(processWrittenMovie(int)));
     }
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     d->process.write( (char*) screenshot.bits(), screenshot.sizeInBytes() );
-#else
-    d->process.write( (char*) screenshot.bits(), screenshot.byteCount() );
-#endif
     for (int i=0; i<30 && d->process.bytesToWrite()>0; ++i) {
         QElapsedTimer t;
         int then = d->process.bytesToWrite();
