@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2014 Sanjiban Bairagya <sanjiban22393@gmail.com>
+// SPDX-FileCopyrightText: 2014 Sanjiban Bairagya <sanjiban22393@gmail.com>
 //
 
 #ifndef PLAYBACKITEM_H
@@ -25,7 +20,7 @@ class PlaybackItem : public QObject
 {
     Q_OBJECT
 public:
-    virtual ~PlaybackItem();
+    ~PlaybackItem() override;
     virtual void play() = 0;
     virtual void pause() = 0;
     virtual void seek( double position ) = 0;
