@@ -1,13 +1,8 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2013 Mihail Ivchenko <ematirov@gmail.com>
-// Copyright 2014 Sanjiban Bairagya <sanjiban22393@gmail.com>
-// Copyright 2014 Illya Kovalevskyy <illya.kovalevskyy@gmail.com>
+// SPDX-FileCopyrightText: 2013 Mihail Ivchenko <ematirov@gmail.com>
+// SPDX-FileCopyrightText: 2014 Sanjiban Bairagya <sanjiban22393@gmail.com>
+// SPDX-FileCopyrightText: 2014 Illya Kovalevskyy <illya.kovalevskyy@gmail.com>
 //
 
 #ifndef WAITEDITWIDGET_H
@@ -29,7 +24,7 @@ class WaitEditWidget: public QWidget
     Q_OBJECT
 
 public:
-    WaitEditWidget( const QModelIndex& index, QWidget* parent=0 );
+    explicit WaitEditWidget( const QModelIndex& index, QWidget* parent=nullptr );
     bool editable() const;
 
 Q_SIGNALS:
