@@ -5,6 +5,8 @@
 
 
 #include <MarbleQuickItem.h>
+#include <QQuickWindow>
+#include <QScreen>
 #include <QPainter>
 #include <QPaintDevice>
 #include <QtMath>
@@ -271,6 +273,7 @@ namespace Marble
 
     void MarbleQuickItem::resizeMap()
     {
+
         d->m_map.setSize(qMax(100, int(width())), qMax(100, int(height())));
         update();
         updatePositionVisibility();
@@ -368,6 +371,18 @@ namespace Marble
         painter->end();
         {
             GeoPainter geoPainter(paintDevice, d->m_map.viewport(), d->m_map.mapQuality());
+
+            double scale = 1.0;
+            // For HighDPI displays take QT_SCALE_FACTOR into account:
+            QQuickWindow * window = this->window();
+            if (window) {
+                QScreen * screen = window->screen();
+                scale = screen != nullptr ? screen->devicePixelRatio() : 1.0;
+                if (scale != 1) {
+                    geoPainter.scale(scale, scale);
+                }
+            }
+
             d->m_map.paint(geoPainter, rect);
         }
         painter->begin(paintDevice);
