@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2014      Sanjiban Bairagya <sanjiban22393@gmail.com>
+// SPDX-FileCopyrightText: 2014 Sanjiban Bairagya <sanjiban22393@gmail.com>
 //
 
 #ifndef GEODATACREATE_H
@@ -28,7 +23,7 @@ public:
 
     GeoDataCreate( const GeoDataCreate &other );
 
-    ~GeoDataCreate();
+    ~GeoDataCreate() override;
 
     GeoDataCreate& operator=( const GeoDataCreate &other );
 
@@ -38,7 +33,7 @@ public:
     GeoDataFeature * clone() const override;
 
     /** Provides type information for downcasting a GeoNode */
-    virtual const char* nodeType() const;
+    const char* nodeType() const override;
 
 private:
     Q_DECLARE_PRIVATE(GeoDataCreate)
