@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2009      Patrick Spendrin <ps_ml@gmx.de>
+// SPDX-FileCopyrightText: 2009 Patrick Spendrin <ps_ml@gmx.de>
 //
 
 #ifndef MARBLE_GEODATAPOLYGONPRIVATE_H
@@ -13,7 +8,6 @@
 
 #include "GeoDataGeometry_p.h"
 
-#include "GeoDataTypes.h"
 #include "GeoDataLinearRing.h"
 
 namespace Marble
@@ -34,23 +28,13 @@ class GeoDataPolygonPrivate : public GeoDataGeometryPrivate
     {
     }
 
-    virtual GeoDataGeometryPrivate* copy()
+    GeoDataGeometryPrivate *copy() const override
     { 
          GeoDataPolygonPrivate* copy = new  GeoDataPolygonPrivate;
         *copy = *this;
         return copy;
     }
 
-    virtual const char* nodeType() const
-    {
-        return GeoDataTypes::GeoDataPolygonType;
-    }
-
-    virtual EnumGeometryId geometryId() const
-    {
-        return GeoDataPolygonId;
-    }
-
     GeoDataLinearRing           outer;
     QVector<GeoDataLinearRing>  inner;
     bool                        m_dirtyBox; // tells whether there have been changes to the
