@@ -5,7 +5,7 @@
 
 #if KRUNNER_VERSION >= QT_VERSION_CHECK(5, 72, 0)
 using namespace Marble;
-K_EXPORT_PLASMA_RUNNER_WITH_JSON(PlasmaRunner, "plasma-runner-marble.json")
+K_PLUGIN_CLASS_WITH_JSON(PlasmaRunner, "plasma-runner-marble.json")
 #else
 K_EXPORT_PLASMA_RUNNER(marble, Marble::PlasmaRunner)
 #endif
