@@ -1,11 +1,6 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2005-2007 Torsten Rahn <tackat@kde.org>
+// SPDX-FileCopyrightText: 2005-2007 Torsten Rahn <tackat@kde.org>
 //
 
 #include "MarbleNavigatorPlugin.h"
@@ -49,7 +44,7 @@ QString MarbleNavigatorPlugin::group() const
 
 QIcon MarbleNavigatorPlugin::icon() const
 {
-    return QIcon(":/icons/marble.png");
+    return QIcon(QStringLiteral(":/icons/marble.png"));
 }
 
 QString MarbleNavigatorPlugin::toolTip() const
